<?
########## Confixx(R) 3.0 Professional ############
####### Copyright SWsoft, Inc. 2004-2005 ##########
#### http://www.sw-soft.com - info@sw-soft.com ####

?>
<html>
<head>
<title>Parallels Confixx</title>
</head>
  <frameset cols ="230,*" border=0 frameborder=0 framespacing=0>
    <frame name=menu             src="menu.php?num=1" marginheight=0 marginwidth=0 scrolling=auto noresize frameborder=0>
    <frame name=content    src="allgemein_start.php" marginheight=0 marginwidth=0 scrolling=auto noresize frameborder=0>
  </frameset>
</html>
